@@ -23,7 +23,8 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <gconf/gconf-client.h>
 #include <glibtop.h>
-#include <pthread.h>
+#include <glibtop/close.h>
+#include "load-graph.h"
 #include "procman.h"
 #include "interface.h"
 #include "proctable.h"
@@ -31,12 +32,11 @@
 #include "favorites.h"
 #include "callbacks.h"
 
-GtkWidget *app;
+static GtkWidget *app = NULL;
 static int simple_view = FALSE;
-pthread_t thread;
 
 
-struct poptOption options[] = {
+static const struct poptOption options[] = {
   {
     "simple",
     's',
@@ -369,7 +369,7 @@ procman_free_data (ProcData *procdata)
 
 	proctable_free_table (procdata);
 	
-	//pretty_table_free (procdata->pretty_table);
+	/* pretty_table_free (procdata->pretty_table); */
 	
 	g_free (procdata);
 	
@@ -534,9 +534,9 @@ main (int argc, char *argv[])
 	GnomeProgram *procman;
 	GConfClient *client;
 	ProcData *procdata;
-	GValue value = {0,};
+	/* GValue value = {0,};
 	poptContext pctx;
-	char **args;
+	char **args; */
 	
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -577,7 +577,7 @@ main (int argc, char *argv[])
 		 
 	
 	if (!app)
-		return 0;  
+		return 1;  
 			
  	gtk_widget_show (app);	
  	
@@ -585,6 +585,8 @@ main (int argc, char *argv[])
 	
 	procman_free_data (procdata);
 
+	glibtop_close ();
+
 	return 0;
 }
 
